@@ -25,7 +25,6 @@
 #include <QPushButton>
 
 #include <KLocalizedString>
-#include <KConfigGroup>
 #include <sonnet/configwidget.h>
 #include "configurationmanager.h"
 
@@ -92,4 +91,3 @@ void MiscPage::saveOptions()
     ConfigurationManager::getInstance()->setHiddenEntriesVisible(m_showHiddenEntries->isChecked());
 }
 
-#include "preferencesdlg.moc"
